import { useEffect, useMemo, useState } from 'react'
import './App.less'
import LoginPop from './pages/loginPop'
import { getInitAppletApi, setVisitLogPushApi, tokenExpireTimeCheckApi, weChatLoginApi } from './api'
import { useAjax } from './hooks/useAjax'
import { removeGameId, removeToken, setGameId, setToken } from './utils/auth'
import { Spin, App as AntdApp, Result } from 'antd'
import RegPop from './pages/regPop'
import MRegPop from './pages/mRegPop'
import PwdPop from './pages/pwdPop'
import useConfig, { Action, State } from './models/useConfig'
import LoginSucc from './pages/loginSucc'
import React from 'react'
import { getRedirectUrl, isOs, isWeChat, isWx } from './utils'
import wllqopenImg from './assets/image/wllqopen.png'

export const DispatchContext = React.createContext<{ dispatch: React.Dispatch<Action>, state: State, getDetails: () => void } | null>(null);

function App() {

	/**************************************/
	const [isLoding, setIsLoding] = useState<boolean>(true)
	const url = window.location.href;
	const searchParams = new URLSearchParams(new URL(url).search);
	const gameId = searchParams.get('game_id')
	const isSw = searchParams.get('isSw')
	const vt = searchParams.get('vt')
	const { state, dispatch, getDetails } = useConfig()
	const { typeSwitch, token } = state
	// const [isInit, setIsInit] = useState<boolean>(false)
	const [isShowLogin, setIsShowLogin] = useState<boolean>(false)
	const [isPhoneWxShow, setIsPhoneWxShow] = useState<boolean>(true)
	const [isShow, setIsShow] = useState<boolean>(true)

	const getInitApplet = useAjax(() => getInitAppletApi())
	const weChatLogin = useAjax((params) => weChatLoginApi(params))
	const setVisitLogPush = useAjax((params) => setVisitLogPushApi(params))
	const tokenExpireTimeCheck = useAjax(() => tokenExpireTimeCheckApi())
	/**************************************/

	useEffect(() => {
		// sw
		if (isSw) {
			localStorage.setItem("isSw", isSw)
		}
		function handleOrientationChange() {
			let orientationType = 'VERTICAL'
			if (window.matchMedia("(orientation: landscape)").matches) { // 横屏
				console.log('横屏')
				orientationType = 'LANDSCAPE'
			} else { // 竖屏
				console.log('竖屏')
				orientationType = 'VERTICAL'
			}
			dispatch({ type: 'setOrientation', params: { orientation: orientationType } })
		}
		handleOrientationChange()
		function handlePopstate() {
			window.history.pushState(null, '');
		}
		handlePopstate()
		// 添加事件监听器
		window.addEventListener("resize", handleOrientationChange);
		window.addEventListener("popstate", handlePopstate);
		// 组件卸载时移除事件监听器
		return () => {
			window.removeEventListener("resize", handleOrientationChange);
			window.removeEventListener("popstate", handlePopstate);
		};
	}, [])

	useEffect(() => {
		if (gameId) {
			setGameId(gameId)
		} else {
			removeGameId()
			removeToken()
			setIsLoding(false)
		}
	}, [gameId])

	useEffect(() => {
		if (vt === '1' && gameId) {
			setVisitLogPush.run({ url: window.location.href })
		}
	}, [vt, gameId])

	// 监听token 获取用户信息
	useEffect(() => {
		if (token) {
			tokenExpireTimeCheck.run().then(res => {
				if (res?.data) {
					init()
					getDetails()
				} else {
					removeToken()
					if (window.location.search?.includes('code')) {
						getRedirectUrl()
					} else {
						window.location.reload()
					}
				}
			})
		} else {
			console.log(gameId)
			if (gameId) {
				if (searchParams.get('code') && isWeChat()) {
					weChatLogin.run({ code: searchParams.get('code') }).then(res => {
						if (+res.code === 200) {
							dispatch({ type: 'setToken', params: { token: res?.data?.token } })
							setToken(res?.data?.token)
						} else {
							getRedirectUrl()
						}
					}).catch(() => getRedirectUrl())
				} else {
					init()
				}
			}
		}
	}, [token])


	const init = () => {
		getInitApplet.run().then(res => {
			setIsLoding(false)
			if (res?.data) {
				let h5WeChatControl = res?.data?.h5GameConfigMap?.h5WeChatControl || 'UN_CONTROL'
				if (h5WeChatControl === 'ONLY_WE_CHAT' && !isWeChat()) {
					window.location.href = "https://open.weixin.qq.com/connect/oauth2/authorize?appid=888"
					return
				}
				dispatch({ type: 'setIsPut', params: { isPut: (res.data.isPut && res.data.appId) || false } })
				document.title = (res.data?.gameName || '游戏-登录')
				dispatch({ type: 'setInitData', params: { initData: { ...res.data, ...res.data?.h5GameConfigMap } } })
				if (res.data?.h5GameConfigMap?.h5SignLogo) {
					let iconLink: any = document.querySelector('link[rel="icon"]');
					iconLink.href = res.data?.h5GameConfigMap?.h5SignLogo
				}
				if (isWx() && ['ios', 'android'].includes(isOs()) && h5WeChatControl === 'UN_WE_CHAT') {
					setIsPhoneWxShow(false)
					return
				}
				if (!searchParams.get('code') && res.data.isPut && res.data.appId && isWeChat()) {
					setIsShowLogin(false)
					window.location.replace(`https://open.weixin.qq.com/connect/oauth2/authorize?appid=${res.data.appId}&redirect_uri=${encodeURIComponent(location.href)}&response_type=code&scope=snsapi_base&state=STATE#wechat_redirect`)
				} else {
					setIsShowLogin(true)
				}
			}
		}).catch(() => setIsLoding(false))
	}

	// 登录注册修改密码
	const Pop = useMemo(() => {
		switch (typeSwitch) {
			case "USER_LOGIN":
				{/* 账号密码登录 */ }
				return <LoginPop />
			case "PHONE_LOGIN":
				{/* 手机登录 */ }
				return <MRegPop type='LOGIN' />
			case "USER_REG":
				{/* 账号密码注册 */ }
				return <RegPop />
			case "PHONE_REG":
				{/* 手机注册 */ }
				return <MRegPop type='REG' />
			case "PWD":
				{/* 找回密码 */ }
				return <PwdPop />
		}
	}, [typeSwitch])


	return <AntdApp>
		<DispatchContext.Provider value={{ dispatch, state, getDetails }}>
			{gameId ? isPhoneWxShow ? <>
				{isLoding ? <div className='loaing'><Spin spinning={true} /></div> : <div style={{ width: '100%', height: '100vh' }}>
					{token ? <LoginSucc /> : isShowLogin ? Pop : <div className='loaing'><Spin spinning={true} /></div>}
				</div>}
			</> : <div style={{ width: '100%', height: '100vh', backgroundColor: '#FFF' }} className='openLlq'>
				{isShow && <div className='zz' onClick={() => { setIsShow(false) }}>
					<img src={wllqopenImg} />
				</div>}
				<Result
					status="403"
					title="请用浏览器打开"
				/>
			</div> : <div style={{ width: '100%', height: '100vh', backgroundColor: '#FFF' }}>
				<Result
					status="404"
					title="游戏ID为空"
					subTitle="请在链接上传入游戏ID"
				/>
			</div>}
		</DispatchContext.Provider>
	</AntdApp>
}

export default App
