import React, { useContext, useEffect, useRef, useState } from 'react';
import '../App.less'
import { useSize } from 'ahooks';
import { DispatchContext } from '../App';
import FloatImg from '../assets/image/f3720cb9e69cb7b8eddfd553b8320442.png'

interface Props {
    isVer: boolean
    onClick?: React.MouseEventHandler<HTMLDivElement>
}
/**
 * 
 * @returns 
 */
const FloatingWindow: React.FC<Props> = ({ isVer, onClick }) => {
    console.log('isVer--->', isVer)
    /**********************************/
    const { state: { initData: { h5SignLogo } } } = useContext(DispatchContext)!;
    const [isDragging, setIsDragging] = useState(false);
    const [nowTimer, setNowTimer] = useState<number>(0)
    const [position, setPosition] = useState({ x: 0, y: 200 });
    const ref = useRef(null);
    const size = useSize(ref);
    /**********************************/

    useEffect(() => {
        if (isVer) {
            setPosition({ x: (document.body.clientWidth || 400) / 2, y: 0 });
            setTimeout(() => {
                (ref?.current as any).style.bottom = '-20px';
                (ref?.current as any).style.top = 'auto';
            }, 20)
        } else {
            setPosition({ x: 0, y: 200 })
        }
    }, [isVer, ref])

    const handleMouseDown = (event: React.MouseEvent<HTMLDivElement>) => {
        event.stopPropagation()
        setNowTimer(new Date().getTime())
        setIsDragging(true);
        setPosition({ x: event.clientX, y: event.clientY });
    };

    const handleMouseMove = (event: React.MouseEvent<HTMLDivElement>) => {
        if (isDragging) {
            setPosition({ x: event.clientX, y: event.clientY });
        }
    };

    const handleMouseUp = (e: any) => {
        setIsDragging(false);
        if (new Date().getTime() - nowTimer < 200) {
            onClick?.(e)
        }
        setNowTimer(0)
        let drawW = size?.width || 0;
        let bodyW = document.body.clientWidth;
        let bodyH = document.body.clientHeight;
        let offsetTop = (ref?.current as any).offsetTop || 0
        let offsetLeft = (ref?.current as any).offsetLeft || 0
        if (isVer) {
            if (offsetTop + drawW / 2 < bodyH / 2) {
                setTimeout(() => {
                    (ref?.current as any).style.top = '-20px';
                    (ref?.current as any).style.bottom = 'auto';
                }, 50)
            } else {
                setTimeout(() => {
                    (ref?.current as any).style.bottom = '-20px';
                    (ref?.current as any).style.top = 'auto';
                }, 50)
            }
        } else {
            if (offsetLeft + drawW / 2 < bodyW / 2) {
                // console.log('小于');
                setTimeout(() => {
                    (ref?.current as any).style.left = '-20px';
                    (ref?.current as any).style.right = 'auto';
                }, 50)
            } else {
                // console.log('大于');
                setTimeout(() => {
                    (ref?.current as any).style.right = '-20px';
                    (ref?.current as any).style.left = 'auto';
                }, 50)
            }
        }
    };

    const onTouchStart = (event: React.TouchEvent<HTMLDivElement>) => {
        event.stopPropagation()
        const touch = event.touches[0];
        setPosition({ x: touch.clientX, y: touch.clientY });
    }

    const onTouchMove = (event: React.TouchEvent<HTMLDivElement>) => {
        event.stopPropagation()
        const touch = event.touches[0];
        setPosition({ x: touch.clientX, y: touch.clientY });
    };

    // const clickHandle = (e: React.MouseEvent<HTMLDivElement, MouseEvent>) => {
    //     // if (!isDragging) onClick?.(e)
    // }

    return (
        <div
            ref={ref}
            style={{
                top: position.y - (size?.height ? size?.height / 2 : 0),
                left: position.x - (size?.width ? size?.width / 2 : 0),
                backgroundImage: `url(${h5SignLogo ?? FloatImg})`,
                transform: `${isVer ? 'rotate(90deg)' : 'rotate(0deg)'}`
            }}
            className={`floating-window`}
            onMouseDown={handleMouseDown}
            onMouseMove={handleMouseMove}
            onMouseUp={handleMouseUp}
            onMouseLeave={handleMouseUp}
            onTouchStart={onTouchStart}
            onTouchMove={onTouchMove}
            onTouchEnd={handleMouseUp}
            // onClick={(e) => { e.stopPropagation(); clickHandle(e) }}
        />
    );
};

export default FloatingWindow;
