import { App, Button, Form, Input, Modal } from "antd"
import React from "react"
import '../../App.less'
import { QrcodeOutlined, TabletOutlined } from "@ant-design/icons"
import CodeInput from "../../components/codeInput"
import { useAjax } from "../../hooks/useAjax"
import { bindPhoneApi } from "../../api"
import showMessage from "../../components/showMessage"

interface Props {
    open?: boolean
    onClose?: () => void
    onChange: () => void
}
/**
 * 绑定手机
 * @param param0 
 * @returns 
 */
const BindPhone: React.FC<Props> = ({ onChange, open, onClose }) => {

    /*********************************/
    const [form] = Form.useForm()
    const mobile = Form.useWatch('mobile', form)
    const { message } = App.useApp()

    const bindPhone = useAjax((params) => bindPhoneApi(params))
    /*********************************/

    const onFinish = (values: any) => {
        bindPhone.run(values).then(res => {
            if (+res.code === 200) {
                onChange()
            } else {
                showMessage.error(res.msg || '绑定失败', message)
            }
        })
    };

    return <Modal
        open={open}
        width={310}
        centered={true}
        footer={null}
        keyboard={false}
        maskClosable={false}
        onCancel={(e) => { e.stopPropagation(); onClose?.() }}
        className="authPop"
    >
        <h4 className="float_pop-tit">绑定手机</h4>
        <div style={{ marginTop: 10 }}>
            <Form
                name="bindPhone"
                form={form}
                autoComplete="off"
                onFinish={onFinish}
            >
                <Form.Item name="mobile" style={{ marginBottom: 10 }} rules={[{ required: true, message: '请输入手机号码!' }]}>
                    <Input prefix={<TabletOutlined />} placeholder="请输入手机号码" size="large" />
                </Form.Item>
                <Form.Item name="code" rules={[{ required: true, message: '请输入您的身份证号码!' }]}>
                    <CodeInput mobile={mobile} msgType={3} prefix={<QrcodeOutlined />} placeholder="请输入验证码" size="large" />
                </Form.Item>
                <Form.Item style={{ marginBottom: 10 }}>
                    <Button type="primary" className="form_button" htmlType="submit" loading={bindPhone.loading} size="large">确认</Button>
                </Form.Item>
            </Form>
        </div>
    </Modal>
}

export default React.memo(BindPhone)